/**
 * 线索
 */

import { gongziTableData, xiansuoTableData } from "../data/table/tableData";
import { changeJsonData, getJsonData, getRandomInt } from "../util/tools";


/**
 * 线索
 * 有参数返回对应线索类型数据，没有参数返回全部线索数据
 * @param clueType 线索类型
 * @returns 
 */
export function getClue(clueType?) {
    let excelData = xiansuoTableData();
    
    let clueExcelData = excelData["线索表"].dataList;

    let clueData = {};
    let writeClueAll = {"1727399696222":[]};
    clueExcelData.forEach( info => {
        let {xsid, xsnr, xslx, xslxxf, zs, dhgl} = info;
        if (!clueData[xslx]) clueData[xslx] = [];
        clueData[xslx].push({xsid, xsnr});
        
        writeClueAll["1727399696222"].push({xsid, xsnr, isChoice:false});
    })

    let clueList = [];
    let allClueJson = getJsonData("json/全部线索.json");
    if(!clueType || Object.keys(allClueJson).length === 0) addAllClue(writeClueAll);
    if(clueType) {
        clueData[clueType].forEach( info => {
            allClueJson["1727399696222"].forEach( thisClue => {
                if(info.xsid == thisClue.xsid) {
                    clueList.push(thisClue);
                }
            })
            writeClueAll["1727399696222"].push({xsid:info.xsid, xsnr:info.xsnr, isChoice:false});
        })
    }
    else {
        clueList = allClueJson["1727399696222"];
    }

    if(clueList) {
        clueList.sort( (a, b) => {
            if (a.isChoice === true && b.isChoice === false) {
                return 1;
            } else if (a.isChoice === false && b.isChoice === true) {
                return -1;
            }
            // a.isChoice - b.isChoice
            return 0;
        });
    }
    
    return clueList;
}


/**
 * 添加线索
 * @param clueType 线索类型【SWOT、ROI、竞合】
 * @param xxType 线索细分类型【S、O、W ...】
 * @param xs [{xsid:"", xsnr:""}, ...]
 * @param xsid 线索id: C001
 * @param xsnr 线索内容: ""
 */
export function addClue(clueType, xxType, xs) {
    let jsonData = getJsonData("json/已选择线索.json");
    let baseData = jsonData;

    //isSubmit:false【未提交】、true【提交】
    /**当前线索类型未提交时，可以修改添加线索 */
    if (!baseData["1727399696222"][clueType]["isSubmit"]) {
        for (let i = 0; i < xs.length; i++) {
            baseData["1727399696222"][clueType][xxType].push(xs[i]);
        }

        changeJsonData("json/已选择线索.json", baseData);
        console.log("添加线索成功");
    } else {
        console.log("线索已提交，无法重复提交");
    }

    /**修改全部线索 */
    let allClueJson = getJsonData("json/全部线索.json");
    let allClueData = allClueJson;

    // let changeClue = [];
    xs.forEach( info => {
        let {xsid, xsnr} = info;
        allClueData["1727399696222"].forEach( thisClue => {
            if(xsid == thisClue.xsid) thisClue.isChoice = true; 
        })
    });
    
    changeJsonData("json/全部线索.json", allClueData);
    
    return "添加线索成功";
}


/**
 * 提交线索
 * @param clueType  线索类型【SWOT、ROI、竞合】
 */
export function submitClue(clueType) {
    let jsonData = getJsonData("json/已选择线索.json");
    let baseData = jsonData;

    //isSubmit:false【未提交】、true【提交】
    baseData["1727399696222"][clueType]["isSubmit"] = true;
    changeJsonData("json/已提交线索.json", baseData);
    console.log("已提交线索");

    /**清空原有剧情和线索 */
    restart();

    return "已提交线索";
}


/**
 * 添加全部线索
 * @param clueType  线索类型【SWOT、ROI、竞合】
 */
 export function addAllClue(data) {
    let jsonData = getJsonData("json/全部线索.json");
    let baseData = jsonData;

    //isChoice:false【未选择】、true【已选择】
    if (Object.keys(baseData).length === 0 || !baseData) {
        changeJsonData("json/全部线索.json", data);
        console.log("已添加全部线索");
    }

}


/**
 * 回显细分线索
 * @param clueType  线索类型【SWOT、ROI、竞合】
 */
export function getChoiceClue(clueType) {
    let jsonData = getJsonData("json/已选择线索.json");
    let baseData = jsonData["1727399696222"];

    return baseData[clueType];
}


/**
 * 取消选中的线索
 * @param clueType 线索类型【SWOT、ROI、竞合】
 * @param xxType 线索细分类型【S、O、W ...】
 * @param xsid 线索id: C001
 * @returns 
 */
export function delClue(clueType, xxType, xsid) {
    let jsonData = getJsonData("json/已选择线索.json");
    let baseData = jsonData;

    let clueData = baseData["1727399696222"][clueType][xxType];
    /**过滤掉xsid的元素 */
    let clueDelData = clueData.filter(x => ![xsid].includes(x.xsid));
    baseData["1727399696222"][clueType][xxType] = clueDelData;
    changeJsonData("json/已选择线索.json", baseData);
    console.log(baseData);

    let allClueJson = getJsonData("json/全部线索.json");
    // let allClueData = allClueJson;
    allClueJson["1727399696222"].forEach( thisClue => {
        if(xsid == thisClue.xsid) thisClue.isChoice = false; 
    });
    changeJsonData("json/全部线索.json", allClueJson);

    return "删除成功";
}




export function getWages(gr:string) {
    let excelData = gongziTableData();
    let wagesExcelData = excelData['工资表'].dataList;

    let wagesData = {};
    wagesExcelData.forEach( info => {
        let nlz = getRandomInt(info.nlfwksz, info.nlfwjsz);
        let xqz = getRandomInt(0, info.xqz);
        let cl = nlz*xqz;
        let gz = nlz*2;
        wagesData[info.gr] = {nlz, xqz, cl, gz};
    })

    return wagesData[gr];
}


/**
 * 统计线索数量
 * @param clueType 
 * @returns 
 */
export function getCount() {
    let jsonData = getJsonData("json/已选择线索.json");
    let clueData = jsonData["1727399696222"];

    let personalData = {
        clue:0,
        tael:0,
        hire:0
    };

    // 线索数
    for(let type in clueData) {
        for(let key in clueData[type]) {
            if (key != "isSubmit") personalData.clue += clueData[type][key].length;
        }
    }

    // 银两数
    let baseData = getJsonData("json/基础数据.json");
    personalData.tael = baseData["1727399696222"]["结算"] || 0;

    // 雇佣人数


    return personalData;
}


/**
 * 基础数据【当前天数、银两数】
 * @returns 
 */
export function getBaseData() {
    let baseData = getJsonData("json/基础数据.json");
    let basicsData = {
        day:0,
        tael:0
    }
    basicsData.day = baseData["1727399696222"]["天数"];
    basicsData.tael = baseData["1727399696222"]["结算"];

    return basicsData;
}


/**结算页面 */
export function getSettlement(clueType) {
    let jsonData = getJsonData("json/已提交线索.json");
    let clueData = jsonData["1727399696222"][clueType];
    let baseData = getJsonData("json/基础数据.json");

    let settlement = {
        isPass:89,
        clue:0,
        tael:0,
        hire:0
    };

    //是否通关
    // let defaultMoney = baseData["1727399696222"]["初始资金"];
    let endMoney = baseData["1727399696222"]["结算"];
    // if (endMoney > defaultMoney) settlement.isPass = "通关"

    // 线索数
    for(let key in clueData) {
        if (key != "isSubmit") settlement.clue += clueData[key].length;
    }

    // 银两数
    settlement.tael = endMoney;

    // 雇佣人数


    return settlement;
}


/**
 * 清空原有剧情和线索
 */
export function restart() {
    let yxzxs = {
        "1727399696222":{
            "SWOT":{
                "isSubmit":false,
                "S":[],
                "W":[],
                "O":[],
                "T":[]
            },
            "ROI":{
                "isSubmit":false,
                "R":[],
                "I":[]
            },
            "竞合":{
                "isSubmit":false,
                "供应商":[],
                "行业竞争":[],
                "跨界竞争":[],
                "潜在替代":[],
                "消费者":[]
            }
        }
    };
    changeJsonData("json/已选择线索.json", yxzxs);

    let jsonData = getJsonData("json/全部线索.json");
    let qbData = {"1727399696222":[]};
    jsonData["1727399696222"].forEach( info => {
        let isChoice = false;
        info.isChoice = isChoice;
        qbData[1727399696222].push(info);
    })

    changeJsonData("json/全部线索.json", qbData);
    let jcsj = {
        "1727399696222":{
            "初始资金": 500, 
            "天数":1, 
            "结算":500
        }
    };
    changeJsonData("json/基础数据.json", jcsj);
    console.log("已清空内容");

    return true;
}




/**
 * 回显线索选择弹窗 停用
 * @param clueType 线索类型【SWOT、ROI、竞合】
 * @param xxType 线索细分类型【S、O、W ...】
 */
 export function choiceClueAll() {
    let allClueJson = getJsonData("json/全部线索.json");
    let clueData = allClueJson["1727399696222"];
    clueData.sort( (a, b) => {
        if (a.isChoice === true && b.isChoice === false) {
            return 1;
        } else if (a.isChoice === false && b.isChoice === true) {
            return -1;
        }
        // a.isChoice - b.isChoice
        return 0;
    });

    return clueData;
}









