/**
 * 总路由入口
 */

import * as asyncHandler from 'express-async-handler';
import * as playBiz from '../biz/play';
import * as clueBiz from '../biz/clue';


export function setRouter(httpServer){
    httpServer.post('/play', asyncHandler(getPlay));
    httpServer.post('/npc', asyncHandler(getNPC));
    httpServer.post('/clue', asyncHandler(getClue));
    httpServer.post('/addclue', asyncHandler(addClue));
    httpServer.post('/submitclue', asyncHandler(submitClue));
    httpServer.post('/choiceclue', asyncHandler(getChoiceClue));
    httpServer.post('/delclue', asyncHandler(delClue));
    // httpServer.post('/choiceclueall', asyncHandler(choiceClueAll));
    httpServer.post('/wages', asyncHandler(getWages));
    httpServer.post('/personal', asyncHandler(getCount));
    httpServer.post('/settlement', asyncHandler(getSettlement));
    httpServer.post('/restart', asyncHandler(restart));
    httpServer.post('/basedata', asyncHandler(getBaseData));
}



/**
 * 剧情
 * @param req 
 * @param res 
 */
function getPlay(req, res) {
    // 商行、SO11、对话Id(后置剧情id)
    let {type, playId, dhId} = req.body;

    let result = playBiz.getPlayData(type, playId, dhId);
    res.success(result);
}


/**
 * NPC
 * @param req 
 * @param res 
 */
function getNPC(req, res) {
    let {type} = req.body;

    let result = playBiz.getNPCData(type);
    res.success(result);
}



/**
 * 线索
 * 有参数返回对应线索类型数据，没有参数返回全部线索数据
 * @param req 
 * @param res 
 */
function getClue(req, res) {
    let {clueType} = req.body;

    let result;
    if(clueType) result = clueBiz.getClue(clueType);
    else result = clueBiz.getClue();

    res.success(result);
}


/**
 * 线索选择
 * @param req 
 * @param res 
 */
function addClue(req, res) {
    let {clueType, xxType, xs} = req.body;

    let result = clueBiz.addClue(clueType, xxType, xs);
    res.success(result);
}


/**
 * 线索提交
 * @param req 
 * @param res 
 */
function submitClue(req, res) {
    let {clueType} = req.body;

    let result = clueBiz.submitClue(clueType);
    res.success(result);
}


/**
 * 回显
 * @param req 
 * @param res 
 */
function getChoiceClue(req, res) {
    let {clueType} = req.body;

    let result = clueBiz.getChoiceClue(clueType);
    res.success(result);
}


/**取消选中线索 */
function delClue(req, res) {
    let {clueType, xxType, xsid} = req.body;

    let result = clueBiz.delClue(clueType, xxType, xsid);
    res.success(result);
}


/**统计获得线索数 */
function getCount(req, res) {
    let result = clueBiz.getCount();
    res.success(result);
}


/**基础数据 */
function getBaseData(req, res) {
    let result = clueBiz.getBaseData();
    res.success(result);
}


/**结算页面 */
function getSettlement(req, res) {
    let {clueType} = req.body;

    let result = clueBiz.getSettlement(clueType);
    res.success(result);
}


/**重新开始 */
function restart(req, res) {
    let result = clueBiz.restart();
    res.success(result);
}


/**
 * 线索选择弹窗回显
 * @param req 
 * @param res 
 */
function choiceClueAll(req, res) {
    let result = clueBiz.choiceClueAll();
    res.success(result);
}


/**
 * 工人
 * @param req gr:工人等级【初级、中级、高级】
 * @param res 
 */
function getWages(req, res) {
    let {gr} = req.body;

    let result = clueBiz.getWages(gr);
    res.success(result);
}










